import os
from collections import namedtuple
from os.path import exists
from pathlib import Path

from dotenv import load_dotenv

MACHINE = namedtuple('MACHINE', ['NAME', 'PROCESS', 'PROTOCOL'])

MACHINE_APP = {
    # Configurations server
    'IP_SERVER': os.environ.get('IP_SERVER'),

    'PORT_SERVER': os.environ.get('PORT_SERVER'),

    # Conf adicional protocolo TCP
    'IP_MACHINE': os.environ.get('IP_MACHINE'),
    'PORT_MACHINE': os.environ.get('PORT_MACHINE'),

    # Auth
    'SFC_USER': os.environ.get('SFC_USER'),
    'SFC_PASS': os.environ.get('SFC_PASS'),

    'NAME_MACHINE': os.environ.get('NAME_MACHINE'),
    'PROTOCOL': os.environ.get('PROTOCOL'),  # Tipos possiveis: GPIO, RS232, TCP
    'PROCESS': os.environ.get('PROCESS'),

    # Conf adicional protocolo RS232
    'PORT_COM': os.environ.get('PORT_COM'),

    # Conf adicional protocolo GPIO
    'GPIO_PIN': os.environ.get('GPIO_PIN'),

    'COMMAND_READ_MACRO': os.environ.get('COMMAND_READ_MACRO'),  # ?Q600 XX Adicionar o numero da macro.
    'COMMAND_WRITE_MACRO': os.environ.get('COMMAND_WRITE_MACRO'),  # ?Q600 XX Adicionar o numero da macro.
    'COMMAND_READ_STATUS': os.environ.get('COMMAND_READ_STATUS'),

    'ROOT_DIR': os.environ.get('ROOT_DIR'),
    'UPDATE_URL': os.environ.get('UPDATE_URL'),
    'EXECUTABLE_FILE': os.environ.get('EXECUTABLE_FILE')
}


def create_machine_app_conf():
    global MACHINE_APP
    machine_app_path = os.path.join(str(Path.home()), '.machine.conf')
    if not exists(machine_app_path):
        with open(machine_app_path, 'w+') as file:
            for k, v in MACHINE_APP.items():
                file.write(f'{k}={v}\n')


class Config:
    machine_conf_path = os.path.join(str(Path.home()), '.machine.conf')
    dirname = os.path.dirname(__file__)
    if exists(machine_conf_path):
        load_dotenv(machine_conf_path)

    create_machine_app_conf()

    DLL_CONF = os.path.join(dirname, 'aaeonEAPI.dll')

    IP_SERVER = os.environ.get('IP_SERVER')
    PORT_SERVER = os.environ.get('PORT_SERVER')

    SFC_USER = os.environ.get('SFC_USER')
    SFC_PASS = os.environ.get('SFC_PASS')

    IP_MACHINE = os.environ.get('IP_MACHINE')
    PORT_MACHINE = os.environ.get('PORT_MACHINE')

    PORT_COM = os.environ.get('PORT_COM')
    GPIO_PIN = int(os.environ.get('GPIO_PIN'))

    TARGET = MACHINE(os.environ.get('NAME_MACHINE'), os.environ.get('PROCESS'), os.environ.get('PROTOCOL'))

    COMMAND_READ_MACRO = os.environ.get('COMMAND_READ_MACRO')
    COMMAND_WRITE_MACRO = os.environ.get('COMMAND_WRITE_MACRO')
    COMMAND_READ_STATUS = os.environ.get('COMMAND_READ_STATUS')

    UPDATE_URL = os.environ.get('UPDATE_URL')
    ROOT_DIR = os.environ.get('ROOT_DIR')
    EXECUTABLE_FILE = os.environ.get('EXECUTABLE_FILE')
