import os
import pathlib
import shutil
import sys
from distutils.util import strtobool

from PyQt5 import QtGui, QtWidgets, QtCore

import actions
import variables
from config import Config
from manager import Manager


class SystemTrayIcon(QtWidgets.QSystemTrayIcon):

    def __init__(self, icon, parent=None):
        QtWidgets.QSystemTrayIcon.__init__(self, icon, parent)
        menu = QtWidgets.QMenu(parent)
        exitAction = menu.addAction("Exit", self.exit)
        self.setContextMenu(menu)

    def exit(self):
        QtCore.QCoreApplication.exit()


def main():
    print('main: ', variables.SYSTEM_VERSION)
    app = QtWidgets.QApplication(sys.argv)

    w = QtWidgets.QWidget()

    dirname = os.path.dirname(__file__)
    icon_path = os.path.join(dirname, 'cog.ico')

    tray_icon = SystemTrayIcon(QtGui.QIcon(icon_path), w)

    # inicio do autoupdate
    update_mode = os.environ.get('UPDATE_MODE') if os.environ.get('UPDATE_MODE') else 'False'
    if strtobool(update_mode):
        actions.change_version()

        update_mode = os.environ.get('UPDATE_MODE') if os.environ.get('UPDATE_MODE') else 'False'
        update_mode_done = os.environ.get('UPDATE_MODE_DONE') if os.environ.get('UPDATE_MODE_DONE') else 'False'

        if not update_mode and update_mode_done:
            tray_icon.exit()

    else:
        actions.get_update()  # verifica se tem atualizacao disponivel
        update_mode = os.environ.get('UPDATE_MODE') if os.environ.get('UPDATE_MODE') else 'False'

        if strtobool(update_mode):
            tray_icon.exit()  # encerra o programa pois é iniciada a nova versao

        else:  # fim do autoupdate remove pasta temporaria da atualizacao
            temp_path = os.environ.get('TEMP_UPDATE_PATH')
            if temp_path:
                temp_path = pathlib.Path(temp_path).parent.resolve()
                shutil.rmtree(temp_path, ignore_errors=True)

            tray_icon.show()

            manager = Manager(Config.TARGET)
            manager.run()

            sys.exit(app.exec_())


if __name__ == '__main__':
    main()
