import json
import urllib.parse

import requests

import helpers
from config import Config


class SfcRequests(object):

    def __init__(self):
        self.token = self.get_token()
        self.base_url = 'https://{server}:{port}'.format(
            server=Config.IP_SERVER,
            port=Config.PORT_SERVER,
        )
        self.config_sfc_route = 'api/sfc/configuration/'

    def get_token(self):
        try:
            req = requests.post(
                'https://' + Config.IP_SERVER + ':' + Config.PORT_SERVER + '/api/account/token/',
                data={
                    "username": Config.SFC_USER,
                    "password": Config.SFC_PASS,
                },
                verify=False)

            if req.status_code == 200:
                response = json.loads(req.content.decode('utf-8'))
                print("> Auth ok")
                return 'Bearer ' + response['token']

            print("> Auth error")
            return None

        except Exception as ex:
            print(ex)

    def send_count(self, workstation_name, process, quantity):
        req = requests.post(
            'https://' + Config.IP_SERVER + ':' + Config.PORT_SERVER + '/api/v1/raspberry/production/save_no_trace_serial_number/',
            data={
                "workstation_name": workstation_name,
                "process": process,
                "quantity": quantity,
            }, headers={'Authorization': self.token},
            verify=False)

        return True if req.status_code == 201 or req.status_code == 200 else False

    def check_updates(self):
        url = urllib.parse.urljoin(self.base_url, self.config_sfc_route)
        headers = {'Authorization': self.token}
        params = {'key': 'MACHINE_INTEGRATION_VERSION'}
        try:
            response = requests.get(url=url, params=params, headers=headers, timeout=3, verify=False)
            response = helpers.get_response(response=response)
            if response['ok'] and response['data']:
                return response['data'][0]['value']
            return None
        except requests.exceptions.RequestException as ex:
            print(ex)
        return None
